package org.tbasket

import org.tbasket.api.Endpoint
import org.tbasket.compute.IncrementHandler

import java.util.Properties

object EndpointSetup {

    final val EndpointPort        = "endpoint.port"
    final val EndpointPortDefault = "48485"

    def setupEndpoint(config: Properties): Endpoint = {
        Main.LOG.debug("Initializing API endpoint...")
        val endpoint = createEndpoint(config)
        endpoint.bind("counter")(IncrementHandler)
        endpoint
    }

    private def createEndpoint(config: Properties): Endpoint = {
        val port = config
                .getProperty(EndpointPort, EndpointPortDefault) match {
            case s"$port" if port.toIntOption.isDefined => port.toInt
            case v                                      =>
                throw new InternalBasketServerException(s"$EndpointPort property value is wrong: $v must be integer")
        }
        new Endpoint(port)
    }

}
