package org.tbasket.test

import io.circe.parser._
import org.junit.jupiter.api.{Assertions, Test}
import org.tbasket.compute.IncrementHandler
import zio.http.model.Status
import zio.http.{Body, Path, Request, URL}

class IncrementRequestHandler {

    private val url = URL(Path.decode("counter"))

    @Test
    def testMakeIncrement(): Unit = {
        val last     = IncrementHandler.getCounter
        val response = IncrementHandler.post(Request.post(Body.empty, url))
        Assertions.assertEquals(response.status, Status.Ok)
        Assertions.assertEquals(last + 1, IncrementHandler.getCounter)
    }

    @Test
    def testGetIncrement(): Unit = {
        val counter  = IncrementHandler.getCounter
        val response = IncrementHandler.get(Request.post(Body.empty, url))
        for {
            json <- response.body.asString
        } yield parse(json) match {
            case Left(failure) => Assertions.fail(s"returned json is invalid ($failure)")
            case Right(json)   =>
                val valueJsons = json.findAllByKey("value")
                Assertions.assertEquals(1, valueJsons.size)
                val valueCounter = valueJsons.head.asNumber.get.toInt.get
                Assertions.assertEquals(counter, valueCounter)
        }
        Assertions.assertEquals(response.status, Status.Ok)
        Assertions.assertEquals(counter, IncrementHandler.getCounter)
    }

}
